@@ -446,14 +446,16 @@ display_folder_icon(GtkTreeStore *tree_store, gchar *key)
 	pixbuf = gdk_pixbuf_new_from_file(img_file, NULL);
 
 	if (pixbuf) {
+		gchar *mf = get_main_folder();
 		gchar *name = g_hash_table_lookup(rf->hrname_r, key);
 		gchar *folder_name = lookup_feed_folder(name);
 		gchar *full_name = g_build_path(
 					G_DIR_SEPARATOR_S,
-					get_main_folder(),
+					mf,
 					folder_name,
 					NULL);
 		g_free(folder_name);
+		g_free(mf);
 /*folder isn't created yet?*/
 #if (DATASERVER_VERSION >= 2033001)
 		rssi = camel_store_get_folder_info_sync (
